"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateScan = void 0;
const ScanCommand_1 = require("../commands/ScanCommand");
const DynamoDBDocument_1 = require("../DynamoDBDocument");
const DynamoDBDocumentClient_1 = require("../DynamoDBDocumentClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ScanCommand_1.ScanCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.scan(input, ...args);
};
async function* paginateScan(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.ExclusiveStartKey = token;
        input["Limit"] = config.pageSize;
        if (config.client instanceof DynamoDBDocument_1.DynamoDBDocument) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof DynamoDBDocumentClient_1.DynamoDBDocumentClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected DynamoDBDocument | DynamoDBDocumentClient");
        }
        yield page;
        token = page.LastEvaluatedKey;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateScan = paginateScan;
