"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rules = void 0;
const class_transformer_1 = require("class-transformer");
class Rules {
    constructor(init) {
        Object.assign(this, init);
        if (init === undefined) {
            this._ruleSet = {};
        }
    }
    static async Load(opts) {
        const { dbManager, key } = opts;
        const { Item } = await dbManager.ddbDocClient.get({
            TableName: dbManager.tableName,
            Key: { PK: `appName#${key.AppName}`.toLowerCase(), SK: 'rules' },
        });
        const record = (0, class_transformer_1.plainToInstance)(Rules, Item);
        return record;
    }
    get DbStruct() {
        return {
            PK: this.PK,
            SK: this.SK,
            AppName: this.AppName,
            RuleSet: this.RuleSet,
            Version: this.Version,
        };
    }
    async Save(dbManager) {
        // TODO: Validate that all the fields needed are present
        // Save under specific AppName key
        const taskByName = dbManager.ddbDocClient.put({
            TableName: dbManager.tableName,
            Item: this.DbStruct,
        });
        // Save under all Applications key
        const taskByApplications = dbManager.ddbDocClient.put({
            TableName: dbManager.tableName,
            Item: this.DbStruct,
        });
        await Promise.all([taskByName, taskByApplications]);
        // Await the tasks so they can throw / complete
        await taskByName;
        await taskByApplications;
    }
    get PK() {
        return `appName#${this.AppName}`.toLowerCase();
    }
    get SK() {
        return 'rules';
    }
    get AppName() {
        return this._appName;
    }
    set AppName(value) {
        this._appName = value.toLowerCase();
    }
    get RuleSet() {
        return this._ruleSet;
    }
    set RuleSet(value) {
        this._ruleSet = value;
    }
    get Version() {
        return this._version;
    }
    set Version(value) {
        this._version = value;
    }
}
exports.Rules = Rules;
//# sourceMappingURL=rules.js.map