"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Version = void 0;
const class_transformer_1 = require("class-transformer");
var SaveBy;
(function (SaveBy) {
    SaveBy[SaveBy["AppName"] = 0] = "AppName";
})(SaveBy || (SaveBy = {}));
class Version {
    constructor(init) {
        this._keyBy = SaveBy.AppName;
        this._status = 'pending';
        this._startupType = 'iframe';
        this._defaultFile = '';
        this._integrationID = '';
        this._routeIDAppVersion = '';
        this._routeIDAppVersionSplat = '';
        this._url = '';
        this._lambdaARN = '';
        // Save any passed in values over the defaults
        Object.assign(this, init);
    }
    /**
     * Load records for all the versions of an app
     * @param opts
     * @returns
     */
    static async LoadVersions(opts) {
        const { dbManager, key } = opts;
        const { Items } = await dbManager.ddbDocClient.query({
            TableName: dbManager.tableName,
            KeyConditionExpression: 'PK = :pkval and begins_with(SK, :skval)',
            ExpressionAttributeValues: {
                ':pkval': `appName#${key.AppName}`.toLowerCase(),
                ':skval': 'version',
            },
        });
        const records = [];
        if (Items !== undefined) {
            for (const item of Items) {
                const record = (0, class_transformer_1.plainToInstance)(Version, item);
                records.push(record);
            }
        }
        return records;
    }
    /**
     * Load record for a single version of an app
     */
    static async LoadVersion(opts) {
        const { dbManager, key } = opts;
        const { Item } = await dbManager.ddbDocClient.get({
            TableName: dbManager.tableName,
            Key: {
                PK: `appName#${key.AppName}`.toLowerCase(),
                SK: `version#${key.SemVer}`.toLowerCase(),
            },
        });
        const record = (0, class_transformer_1.plainToInstance)(Version, Item);
        return record;
    }
    /**
     * Delete record for a single version of an app
     */
    static async DeleteVersion(opts) {
        const { dbManager, key } = opts;
        await dbManager.ddbDocClient.delete({
            TableName: dbManager.tableName,
            Key: {
                PK: `appName#${key.AppName}`.toLowerCase(),
                SK: `version#${key.SemVer}`.toLowerCase(),
            },
        });
    }
    /**
     * Get PK (primary key / hash key) field value for current KeyBy
     */
    get PK() {
        switch (this._keyBy) {
            case SaveBy.AppName:
                return `appName#${this.AppName}`.toLowerCase();
            default:
                throw new Error('Missing SaveBy handler');
        }
    }
    get DbStruct() {
        return {
            PK: this.PK,
            SK: this.SK,
            AppName: this.AppName,
            SemVer: this.SemVer,
            Type: this.Type,
            StartupType: this.StartupType,
            Status: this.Status,
            DefaultFile: this.DefaultFile,
            IntegrationID: this.IntegrationID,
            RouteIDAppVersion: this.RouteIDAppVersion,
            RouteIDAppVersionSplat: this.RouteIDAppVersionSplat,
            URL: this.URL,
            LambdaARN: this.LambdaARN,
        };
    }
    /**
     * Save this record to DynamoDB
     * @param dbManager
     */
    async Save(dbManager) {
        // TODO: Validate that all the fields needed are present
        // Save under specific AppName key
        this._keyBy = SaveBy.AppName;
        await dbManager.ddbDocClient.put({
            TableName: dbManager.tableName,
            Item: this.DbStruct,
        });
    }
    get SK() {
        switch (this._keyBy) {
            case SaveBy.AppName:
                return `version#${this.SemVer}`.toLowerCase();
            default:
                throw new Error('Missing SaveBy handler');
        }
    }
    get AppName() {
        return this._appName;
    }
    set AppName(value) {
        this._appName = value.toLowerCase();
    }
    get SemVer() {
        return this._semVer;
    }
    set SemVer(value) {
        this._semVer = value;
    }
    get Type() {
        return this._type;
    }
    set Type(value) {
        this._type = value;
    }
    get StartupType() {
        return this._startupType;
    }
    set StartupType(value) {
        this._startupType = value;
    }
    get Status() {
        return this._status;
    }
    set Status(value) {
        this._status = value;
    }
    get DefaultFile() {
        return this._defaultFile;
    }
    set DefaultFile(value) {
        this._defaultFile = value;
    }
    get IntegrationID() {
        return this._integrationID;
    }
    set IntegrationID(value) {
        this._integrationID = value;
    }
    get RouteIDAppVersion() {
        return this._routeIDAppVersion;
    }
    set RouteIDAppVersion(value) {
        this._routeIDAppVersion = value;
    }
    get RouteIDAppVersionSplat() {
        return this._routeIDAppVersionSplat;
    }
    set RouteIDAppVersionSplat(value) {
        this._routeIDAppVersionSplat = value;
    }
    get URL() {
        return this._url;
    }
    set URL(value) {
        this._url = value;
    }
    get LambdaARN() {
        return this._lambdaARN;
    }
    set LambdaARN(value) {
        this._lambdaARN = value;
    }
}
exports.Version = Version;
//# sourceMappingURL=version.js.map