import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { settings } from 'carbon-components';
import React from 'react';
import Link from '../Link';
var prefix = settings.prefix;
describe('Link', function () {
  it('should render an <a> element', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "https://carbondesignsystem.com"
    }, "test"));
    var link = screen.getByRole('link');
    expect(link).toBeInTheDocument();
    expect(link).toHaveClass("".concat(prefix, "--link"));
  });
  it('should inherit the href property', function () {
    var href = 'https://carbondesignsystem.com';
    render( /*#__PURE__*/React.createElement(Link, {
      "data-testid": "link",
      href: href
    }, "test"));
    expect(screen.getByTestId('link')).toHaveAttribute('href', href);
  });
  it('should include child content', function () {
    var child = 'test';
    render( /*#__PURE__*/React.createElement(Link, {
      "data-testid": "link",
      href: "https://carbondesignsystem.com"
    }, child));
    expect(screen.getByTestId('link')).toHaveTextContent(child);
  });
  it('should support a custom class on the element with a link role', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "https://carbondesignsystem.com",
      className: "custom-class"
    }, "test"));
    expect(screen.getByRole('link')).toHaveClass('custom-class');
  });
  it('should support being disabled', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "https://carbondesignsystem.com",
      disabled: true
    }, "test"));
    expect(screen.getByRole('link')).toBeInTheDocument();
    expect(screen.getByRole('link')).not.toHaveAttribute('href');
    expect(screen.getByRole('link')).toHaveAttribute('aria-disabled', 'true');
  });
  it('should support the inline link variant', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "https://carbondesignsystem.com",
      inline: true
    }, "test"));
    expect(screen.getByRole('link')).toHaveClass("".concat(prefix, "--link--inline"));
  });
  it.each(['sm', 'md', 'lg'])('should support the %s size variant', function (size) {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "https://carbondesignsystem.com",
      size: size
    }, "test"));
    expect(screen.getByRole('link')).toHaveClass("".concat(prefix, "--link--").concat(size));
  });
  it('should add rel="noopener" automatically if target="_blank"', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "https://carbondesignsystem.com",
      target: "_blank"
    }, "test"));
    expect(screen.getByRole('link')).toHaveAttribute('rel', 'noopener');
  });
  it('should receive keyboard focus', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "/",
      className: "some-class"
    }, "A simple link"));
    expect(document.body).toHaveFocus();
    userEvent.tab();
    expect(screen.getByText('A simple link')).toHaveFocus();
  });
  it('should not receive keyboard focus when disabled', function () {
    render( /*#__PURE__*/React.createElement(Link, {
      href: "/",
      disabled: true,
      className: "some-class"
    }, "A simple link"));
    expect(document.body).toHaveFocus();
    userEvent.tab();
    expect(document.body).toHaveFocus();
  });
  describe('automated verification testing', function () {
    it('should have no aXe violations', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              render( /*#__PURE__*/React.createElement(Link, {
                href: "/",
                className: "some-class"
              }, "A simple link"));
              _context.next = 3;
              return expect(screen.getByText('A simple link')).toHaveNoAxeViolations();

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    it('should have no Accessibility Checker violations', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              render( /*#__PURE__*/React.createElement("main", null, /*#__PURE__*/React.createElement(Link, {
                href: "/",
                className: "some-class"
              }, "A simple link")));
              _context2.next = 3;
              return expect(screen.getByText('A simple link')).toHaveNoACViolations('Link');

            case 3:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
  });
  describe('Component API', function () {
    it('should support a `ref` on the element with role of link', function () {
      var ref = jest.fn();
      render( /*#__PURE__*/React.createElement(Link, {
        href: "https://carbondesignsystem.com",
        ref: ref
      }, "A simple link"));
      expect(ref).toHaveBeenCalledWith(screen.getByRole('link'));
    });
  });
});