import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { Add16 } from '@carbon/icons-react';
import { render, screen } from '@testing-library/react';
import React from 'react';
import Tag from './';
describe('Tag', function () {
  describe('automated accessibility testing', function () {
    it('should have no Axe violations', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var _render, container;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _render = render( /*#__PURE__*/React.createElement(Tag, {
                type: "red"
              }, "test-tag")), container = _render.container;
              _context.next = 3;
              return expect(container).toHaveNoAxeViolations();

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    it('should have no AC violations', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      var _render2, container;

      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _render2 = render( /*#__PURE__*/React.createElement("main", null, /*#__PURE__*/React.createElement(Tag, {
                type: "red"
              }, "Dog"))), container = _render2.container;
              _context2.next = 3;
              return expect(container).toHaveNoACViolations('Tag');

            case 3:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
  });
  it('should have an appropriate aria-label when (filterable)', function () {
    var children = 'tag content';

    var _render3 = render( /*#__PURE__*/React.createElement(Tag, {
      type: "red",
      filter: true
    }, children)),
        container = _render3.container;

    var button = container.querySelector('[aria-label], [aria-labelledby]');
    var accessibilityLabel = button.getAttribute('aria-label') || button.getAttribute('aria-labelledby'); // This check would mirror our "Accessibility label must contain at least all of visible label"
    // requirement

    expect(accessibilityLabel).toEqual(expect.stringContaining(children));
  });
  it('should allow for a custom label', function () {
    render( /*#__PURE__*/React.createElement(Tag, {
      type: "red"
    }, "Johnny Ramone"));
    expect(screen.getByText('Johnny Ramone')).toBeInTheDocument();
  });
  it('should allow for a custom icon', function () {
    render( /*#__PURE__*/React.createElement(Tag, {
      type: "red",
      renderIcon: function renderIcon() {
        return /*#__PURE__*/React.createElement(Add16, {
          "data-testid": "test"
        });
      }
    }, "Dee Dee Ramone"));
    expect(screen.getByTestId('test')).toBeInTheDocument();
  });
});