/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';
import UnorderedList from '../UnorderedList';
import ListItem from '../ListItem';
import { settings } from 'carbon-components';
import { render, screen } from '@testing-library/react';
var prefix = settings.prefix;
describe('UnorderedList', function () {
  it('should render children as expected', function () {
    render( /*#__PURE__*/React.createElement(UnorderedList, null, /*#__PURE__*/React.createElement(ListItem, null, "Item")));
    expect(screen.getByText('Item')).toBeInTheDocument();
  });
  it('should render nested lists', function () {
    render( /*#__PURE__*/React.createElement(UnorderedList, null, /*#__PURE__*/React.createElement(ListItem, null, "Item"), /*#__PURE__*/React.createElement(UnorderedList, {
      nested: true,
      "data-testid": "nested-list"
    }, /*#__PURE__*/React.createElement(ListItem, null, "Nested"))));
    expect(screen.getByTestId('nested-list')).toHaveClass("".concat(prefix, "--list--nested"));
  });
  it('should add custom className given via className prop', function () {
    render( /*#__PURE__*/React.createElement(UnorderedList, {
      className: "some-class",
      "data-testid": "list"
    }, /*#__PURE__*/React.createElement(ListItem, null, "Item")));
    expect(screen.getByTestId('list')).toHaveClass('some-class');
  });
});