"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _ = require(".");

var _Menu = require("../Menu");

var _react2 = require("@testing-library/react");

var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
describe('OverflowMenu', function () {
  it('should render closed by default', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, null, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));
    var ul = document.querySelector('ul');
    expect(_react2.screen.getByRole('button')).toHaveAttribute('aria-expanded', 'false');
    expect(ul).toBe(null);
  });
  it('should be in an open state after trigger is clicked', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, null, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));

    _userEvent.default.type(_react2.screen.getByRole('button'), 'enter');

    expect(_react2.screen.getByRole('button')).toHaveAttribute('aria-expanded', 'true');
    var ul = document.querySelector('ul');
    expect(ul).toBeInTheDocument();
  });
  it('should add custom classNames', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, {
      className: "extra-class"
    }, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));
    expect(_react2.screen.getByRole('button')).toHaveClass('extra-class');
  });
  it('should set a tab index if one is given', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, {
      "tab-index": "2"
    }, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));
    expect(_react2.screen.getByRole('button')).toHaveAttribute('tab-index', '2');
  });
  it('should set an aria-label if one is given', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, {
      "aria-label": "aria-label"
    }, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));
    expect(_react2.screen.getByRole('button')).toHaveAttribute('aria-label', 'aria-label');
  });
  it('should set an id if one is given', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, {
      id: "custom-id"
    }, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));
    expect(_react2.screen.getByRole('button')).toHaveAttribute('id', 'custom-id');
  });
  it('should close menu on outside click', function () {
    (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_.OverflowMenuV2, null, /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "one"), /*#__PURE__*/_react.default.createElement(_Menu.MenuItem, {
      label: "item",
      className: "test-child"
    }, "two")));

    _userEvent.default.type(_react2.screen.getByRole('button'), 'enter');

    expect(_react2.screen.getByRole('button')).toHaveAttribute('aria-expanded', 'true');

    _userEvent.default.click(document.body);

    expect(_react2.screen.getByRole('button')).toHaveAttribute('aria-expanded', 'false');
  });
});