"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEffectOnce = useEffectOnce;

var _react = require("react");

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * A custom hook which will call the given callback exactly once when your
 * component is initially rendered and effects are first called
 *
 * @param {Function} callback
 */
function useEffectOnce(callback) {
  var savedCallback = (0, _react.useRef)(callback);
  var effectGuard = (0, _react.useRef)(false);
  (0, _react.useEffect)(function () {
    savedCallback.current = callback;
  });
  (0, _react.useEffect)(function () {
    if (effectGuard.current !== true) {
      effectGuard.current = true;
      savedCallback.current();
    }
  }, []);
}