"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEvent = useEvent;
exports.useWindowEvent = useWindowEvent;

var _react = require("react");

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
function useEvent(elementOrRef, eventName, callback) {
  var savedCallback = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    savedCallback.current = callback;
  });
  (0, _react.useEffect)(function () {
    var _elementOrRef$current;

    function handler(event) {
      if (savedCallback.current) {
        savedCallback.current(event);
      }
    }

    var element = (_elementOrRef$current = elementOrRef.current) !== null && _elementOrRef$current !== void 0 ? _elementOrRef$current : elementOrRef;
    element.addEventListener(eventName, handler);
    return function () {
      element.removeEventListener(eventName, handler);
    };
  }, [elementOrRef, eventName]);
}

function useWindowEvent(eventName, callback) {
  var savedCallback = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    savedCallback.current = callback;
  });
  (0, _react.useEffect)(function () {
    function handler(event) {
      if (savedCallback.current) {
        savedCallback.current(event);
      }
    }

    window.addEventListener(eventName, handler);
    return function () {
      window.removeEventListener(eventName, handler);
    };
  }, [eventName]);
}